package ca.uwaterloo.cs.gmysql.data;

public class Edges extends Row {

	private static Edges g_head = null;
	private static Edges g_tail = null;

	public Edges	m_next;
	public String	m_class;
	public String	m_start;
	public String	m_end;

	public Edges(String class1, String start1, String end1)
	{
		m_next  = null;
		m_class = class1;
		m_start = id(start1);
		m_end   = id(end1);

		if (g_head == null) {
			g_head = g_tail = this;
		} else {
			g_tail.m_next = this;
			g_tail        = this;
		}
	}

	public static void create(String schema, String version)
	{
		System.out.print("create table ");
		if (schema != null) {
			System.out.print(schema);
		}
		System.out.println("edges (");
		if (version != null) {
			System.out.println("    version   varchar(255),");
		}
		System.out.println("    class     varchar(255) not null,");
		System.out.println("    start     " + idtype() + ",");
		System.out.println("    end       " + idtype());
		System.out.println(")");
		System.out.println("default character set utf8");
		System.out.println("ENGINE=Innodb;");
		System.out.println("");
	}

	public static void dump(String schema, String version)
	{
		Edges	at;
		char	c;

		if (g_head == null) {
			return;
		}
		System.out.print("insert into ");
		if (schema != null) {
			System.out.print(schema);
		}
		System.out.println("edges values");
		c = ' ';
		for (at = g_head; at != null; at = at.m_next) {
			System.out.print(c);
			System.out.print('(');
			if (version != null) {
				sqlstring(version);
				System.out.print(',');
			}
			sqlstring(at.m_class);
			System.out.print(',');
			idstring(at.m_start);
			System.out.print(',');
			idstring(at.m_end);
			System.out.println(')');
			c = ',';
		}
		System.out.println(';');
		System.out.println("");
	}

	public static void augment(String schema, String version)
	{
		System.out.print("insert into ");
		if (schema != null) {
			System.out.print(schema);
		}
		System.out.println("edges");
		System.out.print("select distinct ");
		if (version != null) {
			sqlstring(version);
			System.out.print(',');
		}
		System.out.println("class, start, end");
		System.out.print  ("  from ");
		if (schema != null) {
			System.out.print(schema);
		}
		System.out.println("edge_attributes t1");
		System.out.println("where (class, start, end) not in");
		System.out.println("      (select class, start, end");
		System.out.print  ("         from ");
		if (schema != null) {
			System.out.print(schema);
		}
		System.out.println("edges");
		System.out.println("      );");
		System.out.println("");
	}

	public static void index(String schema, String version)
	{
		System.out.print("alter table ");
		if (schema != null) {
			System.out.print(schema);
		}
		System.out.println("edges");
		System.out.println("    add index index_edges_start_end_class using btree (start, end, class),");
		System.out.println("    add index index_edges_end_class       using btree (end, class),");
		System.out.println("    add index index_edges_class           using btree (class);");
		System.out.println("");
	}
}

